@@ -1,11 +1,11 @@
 package POEx::IRC::Backend;
-$POEx::IRC::Backend::VERSION = '0.027006';
+$POEx::IRC::Backend::VERSION = '0.028001';
 use strictures 2;
 
 use Carp;
 use Scalar::Util 'blessed';
 
-use IRC::Message::Object 'ircmsg';
+use IRC::Message::Object ();
 
 use Net::IP::Minimal 'ip_is_ipv6';
 
@@ -21,6 +21,11 @@ use POE qw/
 use Socket qw/
   AF_INET AF_INET6
   pack_sockaddr_in
+
+  getnameinfo
+  NI_NUMERICHOST
+  NI_NUMERICSERV
+  NIx_NOSERV
 /;
 
 use Types::Standard -all;
@@ -31,11 +36,19 @@ use Try::Tiny;
 use POEx::IRC::Backend::Connect;
 use POEx::IRC::Backend::Connector;
 use POEx::IRC::Backend::Listener;
-use POEx::IRC::Backend::_Util;
 
 
 sub RUNNING_IN_HELL () { $^O =~ /(cygwin|MSWin32)/ }
 
+sub get_unpacked_addr {
+  my ($sock_packed, %params) = @_;
+  my ($err, $addr, $port) = getnameinfo $sock_packed,
+     NI_NUMERICHOST | NI_NUMERICSERV,
+      ( $params{noserv} ? NIx_NOSERV : () );
+  croak $err if $err;
+  $params{noserv} ? $addr : ($addr, $port)
+}
+
 
 use Moo;
 
@@ -110,11 +123,18 @@ has connectors => (
 has wheels => (
   ## POEx::IRC::Backend::Connect objs
   ## These are our connected wheels.
-  init_arg => undef,
-  is      => 'ro',
-  isa     => HashRef,
-  writer  => '_set_wheels',
-  default => sub { +{} },
+  init_arg  => undef,
+  is        => 'ro',
+  isa       => HashRef,
+  writer    => '_set_wheels',
+  default   => sub { +{} },
+);
+
+has ssl_context => (
+  lazy      => 1,
+  is        => 'ro',
+  writer    => '_set_ssl_context',
+  default   => sub { undef },
 );
 
 
@@ -171,14 +191,15 @@ sub spawn {
     ],
   ) or confess "Failed to spawn POE::Session";
 
-  ##  FIXME document that we need a pubkey + cert for server-side ssl
   if (defined $ssl_opts) {
     confess "expected ssl_opts to be an ARRAY but got $ssl_opts"
       unless ref $ssl_opts eq 'ARRAY';
     my $ssl_err;
     try {
       die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
-      POE::Component::SSLify::SSLify_Options( @$ssl_opts );
+      $self->_set_ssl_context(
+        POE::Component::SSLify::SSLify_ContextCreate( @$ssl_opts )
+      );
       1
     } catch {
       $ssl_err = $_;
@@ -248,7 +269,7 @@ sub _accept_conn {
   if ( $listener->ssl ) {
     try {
       die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
-      $sock = POE::Component::SSLify::Server_SSLify($sock);
+      $sock = POE::Component::SSLify::Server_SSLify($sock, $self->ssl_context);
       $really_ssl = 1
     } catch {
       warn "Could not SSLify (server) socket: $_\n";
@@ -275,6 +296,7 @@ sub _accept_conn {
     )
   );
   my $this_conn = POEx::IRC::Backend::Connect->new(
+    ($listener->has_args ? (args => $listener->args) : () ),
     protocol  => $protocol,
     wheel     => $wheel,
     peeraddr  => $un_p_addr,
@@ -334,10 +356,10 @@ sub _create_listener {
   my ($kernel, $self, %args) = @_[KERNEL, OBJECT, ARG0 .. $#_];
   $args{lc $_} = delete $args{$_} for keys %args;
 
-  my $bindaddr  = $args{bindaddr} || '0.0.0.0';
-  my $bindport  = $args{port}     || 0;
+  my $bindaddr  = delete $args{bindaddr} || '0.0.0.0';
+  my $bindport  = delete $args{port}     || 0;
 
-  my $protocol = ( $args{ipv6} || ip_is_ipv6($bindaddr) ) ? 6 : 4;
+  my $protocol = ( delete $args{ipv6} || ip_is_ipv6($bindaddr) ) ? 6 : 4;
 
   my $wheel = POE::Wheel::SocketFactory->new(
     SocketDomain => ($protocol == 6 ? AF_INET6 : AF_INET),
@@ -351,16 +373,14 @@ sub _create_listener {
 
   my $id = $wheel->ID;
 
-  # FIXME probably useful to have the same extra args behavior
-  #  as Connectors, so resultant Connects could easily be tied to their
-  #  originating Listener ->
   my $listener = POEx::IRC::Backend::Listener->new(
     protocol => $protocol,
     wheel => $wheel,
     addr  => $bindaddr,
     port  => $bindport,
-    idle  => ( $args{idle} || 180 ),
-    ssl   => ( $args{ssl}  || 0 ),
+    idle  => ( delete($args{idle}) || 180 ),
+    ssl   => ( delete($args{ssl})  || 0 ),
+    ( keys %args ? (args => \%args) : () ),
   );
 
   $self->listeners->{$id} = $listener;
@@ -456,7 +476,7 @@ sub _create_connector {
     unless defined $remote_addr and defined $remote_port;
 
   my $protocol =
-      delete($args{ipv6})                                ? 6
+      delete $args{ipv6}                                 ? 6
     : ip_is_ipv6($remote_addr)                           ? 6
     : ( $args{bindaddr} && ip_is_ipv6($args{bindaddr}) ) ? 6
                                                          : 4;
@@ -521,7 +541,9 @@ sub _connector_up {
   if ( $ct->ssl ) {
     try {
       die "Failed to load POE::Component::SSLify" unless $self->has_ssl_support;
-      $sock = POE::Component::SSLify::Client_SSLify($sock);
+      $sock = POE::Component::SSLify::Client_SSLify(
+        $sock, 0, 0, $self->ssl_context
+      );
       $really_ssl = 1
     } catch {
       warn "Could not SSLify (client) socket: $_\n";
@@ -566,8 +588,6 @@ sub _connector_up {
   $kernel->post( $self->controller => 
     ircsock_connector_open => $this_conn
   );
-
-  ## TODO document that we don't set an idle alarm for open Connectors
 }
 
 sub _connector_failed {
@@ -597,7 +617,7 @@ sub _ircsock_input {
   ## FIXME configurable raw events?
 
   $kernel->post( $self->controller => 
-    ircsock_input => $this_conn, ircmsg(%$input)
+    ircsock_input => $this_conn, IRC::Message::Object->new(%$input)
   );
 }
 
@@ -792,7 +812,7 @@ unless caller; 1;
 
 =pod
 
-=for Pod::Coverage has_\w+ RUNNING_IN_HELL
+=for Pod::Coverage has_\w+ RUNNING_IN_HELL get_unpacked_addr
 
 =head1 NAME
 
@@ -861,10 +881,11 @@ L<IRC::Message::Object> objects.
 
 Inspired by L<POE::Component::Server::IRC::Backend> & L<POE::Component::IRC>.
 
-This is a very low-level interface to IRC sockets. See
-L<POEx::IRC::Client::Lite> for an experimental IRC client library using this
-backend (and the L</"SEE ALSO"> section of this documentation for related
-tools).
+This is a very low-level interface to IRC sockets; the goal is to provide all
+the necessary scaffolding to develop stateless or stateful IRC clients and
+daemons. See L<POEx::IRC::Client::Lite> for an experimental IRC client library
+using this backend (and the L</"SEE ALSO"> section of this documentation for
+related tools).
 
 =head2 Attributes
 
@@ -886,7 +907,7 @@ stacked with L</filter_line> (at the time the attribute is built).
 =head3 filter_irc
 
 A L<POE::Filter::IRCv3> instance with B<colonify> disabled, by default (this
-behavior changed in v0.28.x).
+behavior changed in v0.27.2).
 
 A server-side Backend may want a colonifying filter:
 
@@ -907,6 +928,11 @@ HASH of active Listener objects, keyed on their wheel ID.
 
 Returns the backend's session ID.
 
+=head3 ssl_context
+
+Returns the L<Net::SSLeay> Context object, if we have one (or C<undef> if
+not); the context is set up by L</spawn> if C<ssl_opts> are specified.
+
 =head3 wheels
 
 HASH of actively connected wheels, keyed on their wheel ID.
@@ -926,6 +952,11 @@ HASH of actively connected wheels, keyed on their wheel ID.
 
 Creates the backend's L<POE::Session>.
 
+The C<ssl_opts> ARRAY is passed directly to
+L<POE::Component::SSLify/SSLify_ContextCreate>, if present. As of C<v0.28.x>,
+each Backend gets its own L<Net::SSLeay> context object (rather than sharing
+the global context). See L<POE::Component::SSLify> & L<Net::SSLeay>.
+
 =head3 create_connector
 
   $backend->create_connector(
@@ -945,7 +976,8 @@ attempt to establish an outgoing connection immediately.
 
 Unrecognized options are stored in the L<POEx::IRC::Backend::Connector>'s
 C<args> HASH-type attribute; this is passed to successfully created
-L<POEx::IRC::Backend::Connect> instances (as of C<v0.026>).
+L<POEx::IRC::Backend::Connect> instances (as of C<v0.26.x>). Note that the
+reference is shared, not copied.
 
 =head3 create_listener
 
@@ -961,6 +993,11 @@ L<POEx::IRC::Backend::Connect> instances (as of C<v0.026>).
 Attempts to create a L<POEx::IRC::Backend::Listener> 
 that holds a L<POE::Wheel::SocketFactory> listener wheel.
 
+Unrecognized arguments will be added to the Listener object's C<args>
+attribute, which is then passed on to L<POEx::IRC::Backend::Connect> objects
+created by incoming connections to that listener, similar to the behavior
+described in L</create_connector> (as of C<v0.28.x>).
+
 =head3 remove_listener
 
     $backend->remove_listener(
@@ -1122,9 +1159,14 @@ L<POEx::IRC::Backend::Connect>
 Dispatched when a connection wheel has had no input for longer than 
 specified idle time (see L</create_listener> regarding idle times).
 
+Currently these events are only issued for incoming Connects accepted on a
+Listener, not outgoing Connects created by a Connector.
+
 C<$_[ARG0]> is the connection's 
 L<POEx::IRC::Backend::Connect>
 
+See also: L<POEx::IRC::Backend::Connect/ping_pending>
+
 =head3 ircsock_connector_failure
 
 Dispatched when a Connector has failed due to some sort of socket error.
@@ -1207,6 +1249,16 @@ Zlib and SSL are mostly untested.
 
 =head1 SEE ALSO
 
+L<POEx::IRC::Backend::Connect>
+
+L<POEx::IRC::Backend::Connector>
+
+L<POEx::IRC::Backend::Listener>
+
+L<POEx::IRC::Backend::Role::Socket>
+
+L<POEx::IRC::Backend::Role::HasWheel>
+
 L<POEx::IRC::Client::Lite> for an experimental IRC client library using this
 backend.
 
