@@ -1,14 +1,7 @@
 package POEx::IRC::Backend::Connector;
-$POEx::IRC::Backend::Connector::VERSION = '0.027006';
+$POEx::IRC::Backend::Connector::VERSION = '0.028001';
 use Moo;
-with 'POEx::IRC::Backend::Role::Connector';
-
-has args => (
-  lazy      => 1,
-  is        => 'ro',
-  predicate => 1,
-  default   => sub { +{} },
-);
+with 'POEx::IRC::Backend::Role::Socket';
 
 has bindaddr => (
   lazy      => 1,
@@ -36,7 +29,7 @@ Created by L<POEx::IRC::Backend> for outgoing connector sockets.
 These objects contain details regarding 
 L<POEx::IRC::Backend> outgoing connector sockets.
 
-This class consumes L<POEx::IRC::Backend::Role::Connector> and adds the
+This class consumes L<POEx::IRC::Backend::Role::Socket> and adds the
 following attributes:
 
 =head2 bindaddr
@@ -45,15 +38,6 @@ The local address this Connector should bind to.
 
 Predicate: B<has_bindaddr>
 
-=head2 args
-
-Arbitrary metadata attached to this Connector. (By default, this is a HASH.)
-
-This is typically passed on to a successfully spawned
-L<POEx::IRC::Backend::Connect>.
-
-Predicate: B<has_args>
-
 =head1 AUTHOR
 
 Jon Portnoy <avenj@cobaltirc.org>
