@@ -1,5 +1,5 @@
 package POEx::IRC::Backend::Role::HasWheel;
-$POEx::IRC::Backend::Role::HasWheel::VERSION = '0.027006';
+$POEx::IRC::Backend::Role::HasWheel::VERSION = '0.028001';
 use Types::Standard -all;
 
 use Moo::Role;
@@ -14,7 +14,7 @@ has wheel_id => (
 
 has wheel => (
   required  => 1,
-  isa       => InstanceOf['POE::Wheel'],
+  isa       => Maybe[ InstanceOf['POE::Wheel'] ],
   is        => 'ro',
   clearer   => 'clear_wheel',
   writer    => 'set_wheel',
